@@ -15,14 +15,6 @@ use URI::BNode;
 
 RDF::KV::Patch - Representation of RDF statements to be added or removed
 
-=head1 VERSION
-
-Version 0.05
-
-=cut
-
-our $VERSION = '0.05';
-
 =head1 SYNOPSIS
 
     my $patch = RDF::KV::Patch->new;
@@ -48,7 +40,7 @@ has _pos => (
     default => sub { {} },
 );
 
-# negative statements/wildcards
+# negative statements-or-not
 has _neg => (
     is      => 'ro',
     isa     => 'HashRef',
@@ -67,56 +59,6 @@ Stub constructor, nothing of interest.
 
 Add a statement, or set of terms, to the I<add> side of the patch.
 
-This method and its siblings are fairly robust, and can take a wide
-variety of inputs, from triple and quad statements, to individual
-subject/predicate/object/graph objects, to string literals, to
-variable nodes, to undef. They are processed by the following scheme:
-
-=over 4
-
-=item
-
-If passed a L<RDF::Trine::Statement>, it will be unwound into its
-respective components. The C<graph> attribute of a L<quad
-statement|RDF::Trine::Statement::Quad> supersedes any given graph
-parameter.
-
-=item
-
-The empty string, C<undef>, and L<RDF::Trine::Node::Variable> objects
-are considered to be wildcards, which are only legal in the
-I<negative> side of the patch, since they don't make sense on the
-positive side. Placing wildcards in all three of the subject,
-predicate and object positions will raise an exception, because if
-carried out it would completely empty the graph. If you're sure you
-want to do that, you should use another mechanism.
-
-=item
-
-I<Subjects> are coerced from string literals to L<URI> and
-L<URI::BNode> instances and from there to
-L<RDF::Trine::Node::Resource> and L<RDF::Trine::Node::Blank>
-instances, respectively.
-
-=item
-
-I<Predicates> are always coerced from string literals or L<URI> objects
-into L<RDF::Trine::Node::Resource> objects.
-
-=item
-
-I<Objects> are coerced from either string literals or C<ARRAY>
-references into L<RDF::Trine::Node::Literal> instances, the latter
-case mimicking L<that class's
-constructor|RDF::Trine::Node::Literal/new>. URIs or blank nodes must
-already be at least instances of L<URI> or L<URI::BNode>, if not
-L<RDF::Trine::Node::Resource> or L<RDF::Trine::Node::Blank>. Note: the
-empty string is considered a wildcard, so if you want an actual empty
-string, you will need to pass in an L<RDF::Trine::Node::Literal> with
-that value.
-
-=back
-
 =cut
 
 sub _validate {
@@ -197,12 +139,7 @@ sub _validate {
                 }
             }
             elsif ($ref eq 'ARRAY') {
-                my ($lv, $lang, $dt) = @$o;
-                if (ref $dt and Scalar::Util::blessed($dt)) {
-                    $dt = $dt->can('uri_value') ? $dt->uri_value :
-                        $dt->can('as_string') ? $dt->as_string : "$dt";
-                }
-                $o = literal($lv, $lang, $dt);
+                $o = literal(@$o);
             }
             else {
                 # dunno
@@ -332,25 +269,12 @@ sub dont_remove_this {
     my ($s, $p, $o, $g) = _validate(@_);
 }
 
-=head2 apply { $model | $remove, $add }
+=head2 apply $model
 
 Apply the patch to an L<RDF::Trine::Model> object. Statements are
 removed first, then added. Transactions
 (i.e. L<RDF::Trine::Model/begin_bulk_ops>) are your responsibility.
 
-Alternatively, supply the C<remove> and C<add> functions directly:
-
-  sub _remove_or_add {
-    my ($subject, $predicate, $object, $graph) = @_;
-
-    # do stuff ...
-
-    # return value is ignored
-  }
-
-Inputs will be either L<RDF::Trine::Node> objects, or C<undef>, in the
-case of C<remove>.
-
 =cut
 
 sub _node {
@@ -383,8 +307,6 @@ sub _traverse {
                         my ($t, $v) = ($ld =~ /^(.)(.*)$/);
                         my @args = $t ? $t eq '@' ?
                             ($v, undef) : (undef, $v) : ();
-                        # of course the datatype is always a string
-                        # here so no need to check it for blessedness
                         for my $ll (keys %{$gsp->[1]{$ld}}) {
                             my $o = literal($ll, @args);
                             #warn 'lul';
@@ -397,27 +319,24 @@ sub _traverse {
     }
 }
 
-sub _apply {
+sub apply {
     my ($self, $model) = @_;
 
     $model->begin_bulk_ops;
 
     _traverse($self->_neg, sub {
-                  #warn join(' ', map { defined $_ ? $_ : '(undef)' } @_);
+                  warn join(' ', map { defined $_ ? $_ : '(undef)' } @_);
                   # fuuuuuuck this quad semantics shit
                   my @n = map { $_[$_] } (0..3);
 
-                  #warn "found context $n[3]" if defined $n[3];
-
                   $model->remove_statements
                       (defined $n[3] ? @n[0..3] : @n[0..2]) });
     _traverse($self->_pos,
               sub {
-                  #warn "found context $_[3]" if defined $_[3];
                   my $stmt = defined $_[3] ?
                       RDF::Trine::Statement::Quad->new(@_)
                             : RDF::Trine::Statement->new(@_[0..2]);
-                  #warn $stmt->sse;
+                  warn $stmt->sse;
                   $model->add_statement($stmt);
               });
 
@@ -426,17 +345,6 @@ sub _apply {
     1;
 }
 
-sub apply {
-    my ($self, $remove, $add) = @_;
-    return $self->_apply($remove) if Scalar::Util::blessed($remove)
-        and $remove->isa('RDF::Trine::Model');
-
-    _traverse($self->_neg, $remove);
-    _traverse($self->_pos, $add);
-
-    1;
-}
-
 =head1 SEE ALSO
 
 =over 4
